@@ -3,8 +3,8 @@
  *	This will be free software, but only when it is finished.
  */
 
-#include <stdio.h>
 #include "hostenv.h"
+#include <stdio.h>
 
 #ifndef __
 # ifdef __STDC__
@@ -26,18 +26,20 @@
 #include "token.h"
 #include "splay.h"
 
-#ifndef	USE_FCHOWN
+#if 0
+#ifndef	HAVE_FCHOWN
 #define	fchown	(void)
-#endif	/* USE_FCHOWN */
-#ifndef	USE_FCHMOD
+#endif	/* HAVE_FCHOWN */
+#ifndef	HAVE_FCHMOD
 #define	fchmod	(void)
-#endif	/* USE_FCHMOD */
-#ifndef	USE_LSTAT
+#endif	/* HAVE_FCHMOD */
+#ifndef	HAVE_LSTAT
 #define	lstat	stat
-#endif	/* USE_LSTAT */
-#ifndef	USE_SYSLOG
+#endif	/* HAVE_LSTAT */
+#ifndef	HAVE_SYSLOG
 #define	syslog	(void)
-#endif	/* USE_SYSLOG */
+#endif	/* HAVE_SYSLOG */
+#endif
 
 #define	RFC974			/* enable RFC974 compatibility */
 #define RFC976			/* enable RFC976 compatibility */
@@ -161,7 +163,7 @@ typedef enum {	nilUserType,	/* nil */
 
 typedef enum {	normal,		/* nil */
 		Resent,		/* this is a resent- header field */
-		eAuthinfo,	/* authentication info	*/
+		eIdentinfo,	/* identification info		  */
 		eChannel,	/* received by this transport channel (mailer)*/
 		eExternal,	/* external source of info, untrustable */
 		eEnvid,		/* SMTP-DSN ENVID string */
