@@ -3,7 +3,9 @@
  */
 
 #include "hostenv.h"
-#if	!defined(USE_GETDTABLESIZE) && !defined(USE_NOFILE)
+
+#if !defined(HAVE_GETDTABLESIZE)
+#if defined(HAVE_SYS_RESOURCE_H)
 
 #include <sys/resource.h>
 getdtablesize()
@@ -19,9 +21,7 @@ getdtablesize()
         return(res.rlim_cur);
 }
 
-#endif	/* !USE_GETDTABLESIZE */
-
-#ifdef	USE_NOFILE /* XX: AARGH... Linux is sticky thing to port to.. */
+#else /* Brr... what ever... */
 
 int
 getdtablesize()
@@ -29,3 +29,6 @@ getdtablesize()
 	return 256; 
 }
 #endif
+#else
+static int dummy = 0;
+#endif
