@@ -84,7 +84,7 @@ optimize(print, code, eocodep)
 
 again:
 	for (pc = code, npc = ncode; pc < eocode; ++pc) {
-		if (*pc >= ncommands) {	/* unsigned; don't need neg. test */
+		if (*pc >= (unsigned)ncommands) {
 			fprintf(stderr, "%s: unknown opcode %d at %d\n",
 				progname, *pc, pc - code);
 			fprintf(stderr, "%s: previous opcode was %d\n",
