@@ -527,9 +527,10 @@ struct de {
 
 static int
 decmp(a, b)
-	register struct de *a, *b;
+     const void *a, *b;
 {
-	return b->mtime - a->mtime;
+	register const struct de *aa = (struct de *)a, *bb = (struct de *)b;
+	return bb->mtime - aa->mtime;
 }
 
 static int desize, nbsize;
@@ -577,6 +578,7 @@ rd_doit(filename, dirs)
 	char pathbuf[512];
 	char *sh_memlevel = getlevel(MEM_SHCMD);
 	int thatpid;
+	struct stat stbuf;
 
 	*pathbuf = 0;
 	if (*dirs) {	/* If it is in alternate dir, move to primary one,
@@ -631,9 +633,12 @@ rd_doit(filename, dirs)
 	    buf = (char *)realloc(buf, blen);
 	  }
 #endif
-	  if (p) *p = 0;
-	  sprintf(buf, "%s-%d", filename, router_id);
-	  if (p) *p = '-';
+	  /* Figure out its inode number */
+	  if (stat(pathbuf,&stbuf) != 0) return 0; /* Failed ?  Well, skip it */
+	  if (!S_ISREG(stbuf.st_mode))   return 0; /* Not a regular file ??   */
+
+	  sprintf(buf, "%d-%d", stbuf.st_ino, router_id);
+
 	  if (eqrename(pathbuf, buf, 1) < 0)
 	    return 0;		/* something is wrong, erename() complains.
 				   (some other process picked it ?) */
@@ -2122,7 +2127,7 @@ static struct {
 	char	*fyiname;
 	char	*fyitext;
 } fyitable[] = {
-{ FYI_BREAKIN, 1, "breakin",	"external message claims local origin!"	},
+{ FYI_BREAKIN, 0, "breakin",	"external message claims local origin!"	},
 { FYI_BADHEADER, 0, "badheader","message header syntax error!"		},
 { FYI_ILLHEADER, 0, "illheader","null header field name!"		},
 { FYI_NOCHANNEL, 0, "nochannel","a null string input channel was specified" },
@@ -2138,8 +2143,11 @@ optsave(type, e)
 
 	for (i = 0; i < (sizeof fyitable / sizeof fyitable[0]); ++i) {
 		if (type == fyitable[i].fyitype) {
-			if (fyitable[i].fyisave)
-				squirrel(e, fyitable[i].fyitext);
+			if (fyitable[i].fyisave) {
+				char name[20];
+				sprintf(name,"_%s", fyitable[i].fyiname);
+				squirrel(e, name, fyitable[i].fyitext);
+			}
 			fprintf(stderr, "*** %s\n", fyitable[i].fyitext);
 			return;
 		}
