@@ -10,7 +10,7 @@
 /* LINTLIBRARY */
 
 #include "mailer.h"
-#ifdef	USE_GDBM
+#ifdef	HAVE_GDBM_H
 #include <gdbm.h>
 #ifndef	GDBM_VERSION /* In a hope of GDBM 1.7.4 having this #define, and
 			the   gdbm_filefno() function.. */
@@ -330,4 +330,4 @@ modp_gdbm(sip)
 			  stbuf.st_nlink, spt_modcheck);
 	return rval;
 }
-#endif	/* USE_GDBM */
+#endif	/* HAVE_GDBM */
