@@ -57,12 +57,14 @@ struct headerinfo optional_hdrs[] = {
 
 struct headerinfo envelope_hdrs[] = {
 { "authinfo",	nilHeaderSemantics,	nilUserType,	eIdentinfo	},
-{ "identinfo",	nilHeaderSemantics,	nilUserType,	eIdentinfo	},
 { "channel",		AnyWord,	nilUserType,	eChannel	},
+{ "env-end",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
+{ "env-eof",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
 { "envid",	nilHeaderSemantics,	nilUserType,	eEnvid		},
 { "external",	nilHeaderSemantics,	nilUserType,	eExternal	},
 { "from",		AMailboxList,	Sender,		eFrom		},
 { "fullname",		Phrase,		nilUserType,	eFullname	},
+{ "identinfo",	nilHeaderSemantics,	nilUserType,	eIdentinfo	},
 { "loginname",		UserAtDomain,	nilUserType,	ePrettyLogin	},
 { "rcvdfrom",		DomainName,	nilUserType,	eRcvdFrom	},
 { "to",			AddressList,	Recipient,	eTo		},
@@ -71,8 +73,6 @@ struct headerinfo envelope_hdrs[] = {
 { "verbose",		AnyWord,	nilUserType,	eVerbose	},
 { "via",		AnyWord,	nilUserType,	eVia		},
 { "with",		AnyWord,	nilUserType,	eWith		},
-{ "env-eof",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
-{ "env-end",	nilHeaderSemantics,	nilUserType,	eEnvEnd		},
 };
 
 struct semtrans {
@@ -191,41 +191,31 @@ find_header(db, name)
 	char *name;
 {
 	struct spblk *spl;
-	register char *cp, *bp;
+	register char *cp;
 #ifdef	USE_ALLOCA
 	int len = strlen(name);
 	char *buffer = alloca(len+1);
-
-	for (cp = name, bp = buffer; *cp != '\0'; ++cp, ++bp) {
-		if (isascii(*cp) && isupper(*cp))
-			*bp = tolower(*cp);
-		else
-			*bp = *cp;
-	}
-	*bp = '\0';
 #else
-	static int len = 0;
+	static int blen = 0;
 	static char *buffer = NULL;
+	int len;
 
 	if (buffer == NULL) {
-		len = 64;
-		buffer = malloc(len);
+		blen = 64;
+		buffer = malloc(blen);
 	}
-	for (cp = name, bp = buffer; *cp != '\0'; ++cp, ++bp) {
-		if (bp - buffer > len - 2) {
-			register char *nbuffer;
-			len *= 2;
-			nbuffer = realloc(buffer, len);
-			bp = nbuffer + (bp - buffer);
-			buffer = nbuffer;
-		}
-		if (isascii(*cp) && isupper(*cp))
-			*bp = tolower(*cp);
-		else
-			*bp = *cp;
+	len = strlen(name);
+	if ( len >= blen ) {
+	  while (len < blen)
+	    blen <<= 1;
+	  buffer = realloc(buffer, blen);
 	}
-	*bp = '\0';
 #endif
+	strcpy(buffer, name);
+	for (cp = buffer; *cp != '\0'; ++cp) {
+		if (isascii(*cp) && isupper(*cp))
+			*cp = tolower(*cp);
+	}
 
 	if ((spl = sp_lookup(symbol((u_char *)buffer), db)) == NULL)
 		return NULL;
