@@ -11,7 +11,7 @@
 #include <sys/file.h>
 #include "search.h"
 #include "io.h"
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 #include <sys/mman.h>
 #endif
 #include <errno.h>
@@ -20,7 +20,7 @@ extern int cistrcmp();
 extern int deferit;
 extern void v_set();
 
-#ifdef USE_MMAP
+#ifdef HAVE_MMAP
 extern void seq_remap __((struct file_map *, long newsize));
 extern char *mfgets __((char *, int, struct file_map *));
 #endif
@@ -41,7 +41,7 @@ search_seq(sip)
 	spkey_t symid;
 	char buf[BUFSIZ];
 	struct file_map *fm;
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 	struct stat fst;
 #endif
 
@@ -62,7 +62,7 @@ reopen:
 		}
 		fm = (struct file_map *)emalloc(sizeof(struct file_map));
 		fm->fp = fp;
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 		fstat(FILENO(fp),&fst);
 		fm->size = fst.st_size;
 		fm->mtime = fst.st_mtime;
@@ -97,7 +97,7 @@ reopen:
 			spl->data = (u_char *)fm;
 	}
 	fp = fm->fp;
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 	/* This  fstat()  for possible seq_remap() trigger causes a bit
 	   more syscalls, than is really necessary.   Therefore it is
 	   likely best to have "-m" option on the relation definitions
@@ -140,7 +140,7 @@ reopen:
 	}
 	if (!retry && ferror(fp)) {
 		fclose(fp);
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 		if (fm->membuf != NULL)
 		  munmap(fm->membuf,fm->size);
 #endif
@@ -178,7 +178,7 @@ close_seq(sip)
 		return;	/* nothing to flush */
 	spl->data = NULL;	/* Delete the file-entry */
 	fclose(fm->fp);
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 	if (fm->membuf != NULL)
 	  munmap(fm->membuf,fm->size);
 #endif
@@ -196,7 +196,7 @@ open_seq(sip, mode)
 	struct spblk *spl;
 	spkey_t symid;
 	int imode;
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 	struct stat fst;
 #endif
 
@@ -224,7 +224,7 @@ open_seq(sip, mode)
 		}
 		fm = (struct file_map *)emalloc(sizeof(struct file_map));
 		fm->fp = fp;
-#ifdef	USE_MMAP
+#ifdef	HAVE_MMAP
 		fstat(FILENO(fm->fp),&fst);
 		fm->size = fst.st_size;
 		fm->mtime = fst.st_mtime;
@@ -311,7 +311,7 @@ count_seq(sip, outfp)
 	int cnt = 0;
 
 	if ((fp = open_seq(sip, "r")) != NULL) {
-#ifdef USE_MMAP_not
+#ifdef HAVE_MMAP_not
 	  struct file_map *fm;
 	  spkey_t symid = symbol((u_char *)sip->file);
 	  struct spblk *spl = sp_lookup(symid, spt_files);
@@ -396,7 +396,7 @@ modp_seq(sip)
 	return rval;
 }
 
-#ifdef USE_MMAP
+#ifdef HAVE_MMAP
 #ifndef NO_SEQREMAP
 void
 seq_remap(fm,newsize)
@@ -460,9 +460,6 @@ readchunk(file, offset)
 	spkey_t symid;
 	char buf[BUFSIZ];
 	struct file_map *fm;
-#ifdef USE_MMAP
-	struct stat fst;
-#endif
 
 	if (file == NULL || offset < 0)
 		return NULL;
