@@ -55,6 +55,7 @@ extern long elseek();
 extern long offset();
 extern void initline();
 
+static void	reject __((struct envelope *e, char *msgfile));
 
 static void	prctladdr __((struct conscell *info, FILE *fp, int cfflag, char *comment));
 static void	prdsndata __((struct conscell *info, FILE *fp, int cfflag, char *comment));
@@ -127,16 +128,15 @@ run_rfc822(argc, argv)
 		break;
 	case PERR_BADOPEN:
 		break;
-#if 0 /* not used */
 	case PERR_BADCONTINUATION:	/* fatal */
-		defer(e, "continuation line prior to header");
+		squirrel(e, "badenvelope", "continuation line prior to header");
 		break;
 	case PERR_BADSUBMIT:		/* fatal */
-		defer(e, "unrecognized envelope information");
+		squirrel(e, "badsubmit", "unrecognized envelope information");
 		break;
-#endif
 	case PERR_LOOP:			/* fatal */
 		reject(e, "loopexceeded");
+		squirrel(e, "_looped", "loop count exceeded");
 		break;
 	case PERR_ENVELOPE:		/* fatal */
 		reject(e, "envelope");
@@ -151,7 +151,7 @@ run_rfc822(argc, argv)
 		reject(e, "norecipients");
 		break;
 	case PERR_NOSENDER:
-		squirrel(e, "really truly Unknown Sender");
+		squirrel(e, "nosender", "really truly Unknown Sender");
 		break;
 	case PERR_CTRLFILE:
 		defer(e, "ctrlfile");
@@ -162,6 +162,8 @@ run_rfc822(argc, argv)
 
 	if (D_final > 0)
 		dumpInfo(e);
+	if (status != PERR_CTRLFILE && status != PERR_DEFERRED && !savefile)
+		(void) unlink(file); /* SILENT! */
 	if (e->e_fp != NULL)
 		fclose(e->e_fp);
 	tfree(MEM_TEMP);
@@ -186,8 +188,6 @@ makeLetter(e, octothorp)
 	struct header	*h;
 	int		n, inheader;
 	struct header	*ph, *nh;
-	int badcontinuationflag = 0;
-	int badsubmitflag = 0;
 
 	e->e_eHeaders = 0;
 	e->e_headers = 0;
@@ -246,6 +246,12 @@ makeLetter(e, octothorp)
 			} else if (inheader && n > 1) {
 				/* append to the header we just saw */
 				struct token *t;
+				if (e->e_headers == NULL) {
+				  /* Wow, continuation without previous header! */
+				  /* It must be body.. */
+				  repos_getline(e->e_fp, offset(e->e_fp) - n);
+				  break;
+				}
 				t = e->e_headers->h_lines;
 				while (t->t_next != NULL)
 					t = t->t_next;
@@ -253,7 +259,6 @@ makeLetter(e, octothorp)
 				t->t_next->t_type = Line;
 			} else if (!octothorp) {
 				return PERR_BADCONTINUATION;
-				badcontinuationflag = 1;
 			}
 		} else if (!inheader		/* envelope information */
 			   && (*(cp=linebuf-i) == ' ' || *cp == '\t'
@@ -282,7 +287,6 @@ makeLetter(e, octothorp)
 				h->h_contents = hdr_scanparse(e, h, octothorp);
 				h->h_stamp = hdr_type(h);
 				return PERR_BADSUBMIT;
-				badsubmitflag = 1;
 				break;
 			case eFrom:		/* pity to break the elegance */
 				hd = h->h_descriptor;
@@ -294,13 +298,23 @@ makeLetter(e, octothorp)
 				break;
 			case eEnvEnd:		/* more elegance breaks */
 				inheader = 1;
+				/* record start of headers for posterity */
+				e->e_hdrOffset = offset(e->e_fp);
+				e->e_eHeaders = h->h_next;
+				break;
 			default:		/* a real envelope header */
 				h->h_contents = hdr_scanparse(e, h, octothorp);
 				h->h_stamp = hdr_type(h);
 				break;
 			}
-		} else if (!octothorp)
+		} else if (!octothorp) {
+			/* Expected RFC-822 header, and got something else.
+			   We play as if it was the end of the headers, and
+			   start of the body.  Keep the first faulty input
+			   around by reseeking into its start.			*/
+			repos_getline(e->e_fp, offset(e->e_fp) - n);
 			break;
+		}
 	}
 	/* reverse the list of headers so we keep them in the original order */
 	for (ph = NULL, h = e->e_eHeaders; h != NULL; h = nh) {
@@ -327,9 +341,6 @@ makeLetter(e, octothorp)
 	/* record the start of the message body for posterity */
 	e->e_msgOffset = offset(e->e_fp);
 
-	if (badsubmitflag || badcontinuationflag)
-	  squirrel(e, "unrecognized envelope information; entries discarded!");
-
 	return PERR_OK;
 }
 
@@ -464,34 +475,37 @@ char *errors_to = NULL;
 /* Save the message in a directory for the postmaster to view it later */
 
 void
-squirrel(e, text)
+squirrel(e, keyw, text)
 	struct envelope *e;
-	char *text;
+	char *keyw, *text;
 {
 	char *path;
 
 #ifndef	USE_ALLOCA
-	path = emalloc(5+sizeof(POSTMANDIR)+10);
+	path = emalloc(5+sizeof(POSTMANDIR)+10+strlen(keyw));
 #else
-	path = alloca(5+sizeof(POSTMANDIR)+10);
+	path = alloca(5+sizeof(POSTMANDIR)+10+strlen(keyw));
 #endif
-	sprintf(path, "../%s/%d", POSTMANDIR, e->e_statbuf.st_ino);
+	sprintf(path, "../%s/%d.%s", POSTMANDIR, e->e_statbuf.st_ino, keyw);
 
 	/* XX: We make a copy by link()ing file to two dirs, some
 	       systems (Andrew-FS in mind) can't do it! Copying is
 	       ok in their case.. */
 
+	/* If linking to  /postman/  fails, link it to router dir with
+	   two dots at the begin of the name + keyword at the end */
 	if (elink(e->e_file, path) < 0) {
-		sprintf(path, "..%d", e->e_statbuf.st_ino);
-		erename(e->e_file, path);
+		sprintf(path, "..%d.%s", e->e_statbuf.st_ino, keyw);
+		elink(e->e_file, path);
 	}
+
 	/* The successfull squirrel MUST NOT delete the original message! */
 
-	fprintf(stderr, "squirrel: %d saved for inspection: %s\n",
-			e->e_statbuf.st_ino, text);
+	fprintf(stderr, "squirrel: %d.%s saved for inspection: %s\n",
+			e->e_statbuf.st_ino, keyw, text);
 #ifdef	LOG_ERR
-	syslog(LOG_ERR, "%d saved for inspection: %s\n",
-			e->e_statbuf.st_ino, text);
+	syslog(LOG_ERR, "%d.%s saved for inspection: %s\n",
+			e->e_statbuf.st_ino, keyw, text);
 #endif	/* LOG_ERR */
 #ifndef	USE_ALLOCA
 	free(path);
@@ -547,7 +561,7 @@ erraddress(e)
 
 /* Send the message back to originator with user-friendly chastizing errors */
 
-void
+static void
 reject(e, msgfile)
 	struct envelope *e;
 	char *msgfile;
@@ -561,7 +575,7 @@ reject(e, msgfile)
 	fprintf(stderr, "Rejecting because of %s\n", msgfile);
 	
 	if ((h = erraddress(e)) == NULL) {
-		squirrel(e, "No one to return an error to!");
+		squirrel(e, "noerraddr", "No one to return an error to!");
 		return;
 	}
 	/*
@@ -576,7 +590,7 @@ reject(e, msgfile)
 	sprintf(path, "%s/%s/%s", mailshare, FORMSDIR, msgfile);
 	if ((fp = fopen(path, "r")) == NULL) {
 		perror(path);
-		squirrel(e, "Couldn't open reject form file");
+		squirrel(e, "norejform", "Couldn't open reject form file");
 #ifndef	USE_ALLOCA
 		free(path);
 #endif
@@ -586,7 +600,7 @@ reject(e, msgfile)
 	free(path);
 #endif
 	if ((mfp = mail_open(MSG_RFC822)) == NULL) {
-		squirrel(e, "Couldn't open reject message file");
+		squirrel(e, "mailcreatefail", "Couldn't open reject message file");
 		return;
 	}
 	/* who is it from? */
@@ -638,16 +652,15 @@ reject(e, msgfile)
 	rewind(e->e_fp);
 	while ((n = fread(buf, 1, sizeof buf, e->e_fp)) > 0) {
 		if (fwrite(buf, 1, n, mfp) != n) {
-			squirrel(e, "Couldn't include rejected input message");
+			squirrel(e, "mailcreafail", "Couldn't include rejected input message");
 			mail_abort(mfp);
 			return;
 		}
 	}
 	if (mail_close(mfp) < 0) {
-		squirrel(e, "Couldn't close reject message file");
+		squirrel(e, "mailcreafail", "Couldn't close reject message file");
 		mail_abort(mfp);
 	}
-	eunlink(e->e_file);
 }
 
 /* Save a message file away because something went wrong during routing */
@@ -1042,6 +1055,8 @@ iserrmessage()
  * in the right order. It implements the semantics of message processing.
  */
 
+int ReceivedCount = 0;
+
 int
 sequencer(e, file)
 	struct envelope *e;
@@ -1060,7 +1075,6 @@ sequencer(e, file)
 	char vbuf[2048], verbosefile[1024];
 	char *envid = NULL;
 
-
 	errors_to = NULL; /* to be gotten rid off.. */
 
 	if (e == NULL) {
@@ -1079,16 +1093,17 @@ sequencer(e, file)
 		}
 	}
 	/* gross loop checking */
+	ReceivedCount = 0;
 	for (h = e->e_headers, i = 0; h != NULL; h = h->h_next) {
 		if (h->h_descriptor->semantics == Received
 		    || (h->h_descriptor->semantics == nilHeaderSemantics
 			&& CISTREQ(h->h_pname, "Received"))) {
-			if (++i >= maxReceived) {
+			if (++ReceivedCount >= maxReceived) {
+			   if (ReceivedCount == maxReceived)
 				fprintf(stderr,
 				     "%s: looping message, rejected!\n",
 					progname);
 				perr = PERR_LOOP;
-				return perr;
 			}
 		}
 	}
@@ -1116,12 +1131,9 @@ sequencer(e, file)
 		 * the message when the problem is fixed, so we don't tell
 		 * the originator that anything went wrong.
 		 */
-#if 0 /* -- rfc822 processing does a reject() on this! */
-		defer(e, "envelope");
-		/* Often the defer() becomes resubmited via cron, but lets
-		   hope the postmaster will see things manually.. */
-#endif
-		return PERR_ENVELOPE;
+		/* We give precedence to loop-trap error */
+		if (perr == 0)
+			perr = PERR_ENVELOPE;
 	}
 	e->e_from_trusted = makequad();
 	e->e_from_resolved = makequad();
@@ -1146,6 +1158,9 @@ sequencer(e, file)
 				saveAddress(msgidh->h_contents.a->a_tokens);
 	}
 
+	if (perr)
+		return perr;
+
 	/* put pertinent message information in the zsh environment */
 	setenvinfo(e);
 
