@@ -754,7 +754,7 @@ queryipcinit()
 	  perror("socket");
 	  return;
 	}
-	setsockopt(querysocket, SOL_SOCKET, SO_REUSEADDR, &on, sizeof(on));
+	setsockopt(querysocket, SOL_SOCKET, SO_REUSEADDR, (void*)&on, sizeof(on));
 
 	if (bind(querysocket, (struct sockaddr *)&sad, sizeof sad) < 0) {
 	  perror("bind:mailq socket");
