@@ -53,7 +53,11 @@ char *Copyright2= "Copyright 1991-1996 Matti Aarnio";
 #endif
 #include "zmsignal.h"
 #include <errno.h>
-#include <varargs.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h> /* If no  <stdarg.h>,  then presume <varargs.h> ... */
+#endif
 #include "mail.h"
 
 #ifdef  HAVE_WAITPID
@@ -249,7 +253,6 @@ extern u_char *rfc822date __((time_t *));
 static int mvdata __((FILE *, char *));
 static int mvbdata __((FILE *, char *, long, int *));
 extern void type __(());
-static void report __(());
 extern void debug_report __(());
 static void help __(());
 extern time_t time __((time_t *));
@@ -274,6 +277,12 @@ extern char *optarg;
 extern char *strchr(), *strrchr();
 extern int cistrcmp(), cistrncmp();
 
+#ifdef HAVE_STDARG_H
+static void report __((char *cp, ...));
+#else
+static void report __(());
+#endif
+
 #ifndef CISTREQN
 # define   CISTREQN(x, y, n)  (cistrncmp((char *)(x), (char *)(y), n) == 0)
 #endif
@@ -2209,17 +2218,26 @@ tmalloc(n)
  * where it doesn't work.
  */
 
-/* VARARGS */
 static void
+#ifdef HAVE_STDARG_H
+report(char *cp, ...)
+#else
+/* VARARGS */
 report(va_alist)
 	va_dcl
+#endif
 {
 	va_list	ap;
-	char *cp, buf[8192];
+	char buf[8192];
 
+#ifdef HAVE_STDARG_H
+	va_start(ap, cp);
+#else
+	char *cp;
 	va_start(ap);
-	sprintf(buf, "-%s ", rhostname);
 	cp = va_arg(ap, char *);
+#endif
+	sprintf(buf, "-%s ", rhostname);
 #ifdef	HAVE_VPRINTF
 	vsprintf(buf+strlen(buf), cp, ap);
 #else	/* !HAVE_VPRINTF */
