@@ -28,8 +28,8 @@
 #endif	/* TRY_AGAIN */
 #ifdef	BIND
 #undef NOERROR /* Solaris  <sys/socket.h>  has  NOERROR too.. */
-#include "arpa/nameser.h"
-#include "resolv.h"
+#include <arpa/nameser.h>
+#include <resolv.h>
 
 #ifndef	BIND_VER
 #ifdef	GETLONG
