@@ -10,7 +10,11 @@
 #include "hostenv.h"
 #include <stdio.h>
 #include <sysexits.h>
-#include <varargs.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
 #include "mail.h"
 #include "ta.h"
 
@@ -90,6 +94,10 @@ notaryreport(arg1,arg2,arg3,arg4)
 		arg5?arg5:"");
 }
 
+#ifdef HAVE_STDARG_H
+void
+diagnostic(struct rcpt *rp, int rc, int timeout, char *fmt, ...)
+#else
 /*VARARGS*/
 void
 diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remotemsg) */
@@ -97,6 +105,7 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 	int rc, timeout;
 	char *fmt;
 	va_dcl
+#endif
 {
 	char	mark, message[8192];
 	register char *cp, *s, *es, *s2;
@@ -105,7 +114,11 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 
 	rp->status = rc;
 
+#ifdef HAVE_STDARG_H
+	va_start(ap,fmt);
+#else
 	va_start(ap);
+#endif
 	es = &message[sizeof message - 2];
 	for (s = message; fmt != NULL && *fmt != '\0'; ++fmt) {
 		if (s >= es)
