@@ -25,8 +25,8 @@ lockaddr(fd, map, offset, was, new)
 	int	fd;
 	char	*map;
 	long	offset;
-	char	was;
-	char	new;
+	int	was;
+	int	new;
 {
 	char	lockbuf[1+_CFTAG_RCPTPIDSIZE+1];
 	int	newlock = 0;
