@@ -6,7 +6,6 @@
  */
 
 #include "hostenv.h"
-#include <varargs.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include "ta.h"
@@ -228,14 +227,14 @@ if (verboselog) fprintf(verboselog,"8-bit header: '%s'\n",hdr);
 	      /* Now the 's' points at the begin of the token */
 	      p = (u_char*)hdr;
 	      if (!newbuf) {
-		len = strlen(s)*3; /* If it ALL turns into QP */
+		len = strlen((void*)s)*3; /* If it ALL turns into QP */
 		len += ((char*)s - hdr) + 30; /* Slag at the length */
 		newbuf = (u_char*)emalloc(len);
 	      }
 	      /* Copy the head */
 	      q = newbuf;
 	      while (p < s) *q++ = *p++;
-	      strcpy(q,"=?UNKNOWN-8BIT?Q?");
+	      strcpy((void*)q,"=?UNKNOWN-8BIT?Q?");
 	      q += 17; /* 17 chars above */
 
 	      for ( ; *s && (*s != ' ' && *s != '\t' && *s != ')'); ++s) {
@@ -246,8 +245,8 @@ if (verboselog) fprintf(verboselog,"8-bit header: '%s'\n",hdr);
 		} else
 		  *q++ = *s;
 	      }
-	      strcpy(q,"?="); q += 2;
-	      strcpy(q,s);
+	      strcpy((void*)q,"?="); q += 2;
+	      strcpy((void*)q,(void*)s);
 if(verboselog)fprintf(verboselog,"After processing: '%s'\n",newbuf);
 	      ctlfree(rp->desc,*inhdr);
 	      hdr = *inhdr = (char *)newbuf;
