@@ -26,8 +26,12 @@
  */
 
 #include "hostenv.h"
-#include <varargs.h>
 #include <stdio.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
 #include <sys/types.h>
 #include "ta.h"
 
@@ -145,23 +149,32 @@ struct rcpt *rp;
 	return 1;
 }
 
+#ifdef HAVE_STDARG_H
+int
+append_header(struct rcpt *rp, char *fmt, ...)
+#else
 int
 append_header(va_alist)
 	va_dcl
+#endif
 {
 	va_list pvar;
-	struct rcpt *rp;
-	char *fmt;
 	char linebuf[2000]; /* XX: SHOULD be enough..  damn vsprintf()..*/
 	int linelen;
 	int linecnt;
 	char **hdr, ***hdrpp, **hdrp2;
 
-	linebuf[0] = 0;
+#ifdef HAVE_STDARG_H
+	va_start(pvar,fmt);
+#else
+	struct rcpt *rp;
+	char *fmt;
 
 	va_start(pvar);
 	rp  = va_arg(pvar, struct rcpt*);
 	fmt = va_arg(pvar, char *);
+#endif
+	linebuf[0] = 0;
 
 	vsprintf(linebuf, fmt, pvar);
 	va_end(pvar);
@@ -846,9 +859,8 @@ mime_received_convert(rp, convertstr)
 	    fprintf(verboselog,"The new line is: '%s'\n",*inhdr);
 	  }
 
-	  break; /* quit this header munging.. */
+	  inhdr = NULL; /* quit this header munging.. */
 	}
-
 	return 1;
 }
 
