@@ -19,7 +19,6 @@
 #include <errno.h>
 #include <pwd.h>
 #include <sysexits.h>
-#include <varargs.h>
 #include <sys/param.h>
 #include <syslog.h>
 #include <fcntl.h>
@@ -283,6 +282,14 @@ int sig;
 	/* Sigh, actually dummy routine.. */
 }
 
+static int
+free_spu(p)
+     void *p;
+{
+	free(p);
+	return 0;
+}
+
 
 #ifndef	MAXPATHLEN
 #define	MAXPATHLEN 1024
@@ -454,8 +461,7 @@ main(argc, argv)
 	    if (nbp->wantrbiff != 0) {
 	      if (spt_users == NULL)
 		spt_users = sp_init();
-	      sp_install(symbol(nbp->user),
-			 (char *)NULL, 0, spt_users);
+	      sp_install(symbol((void*)nbp->user), NULL, 0, spt_users);
 	    }
 #endif /* RBIFF */
 	  }
@@ -473,12 +479,9 @@ main(argc, argv)
 	    free(nbp->user);
 	    free(nbp);
 	  }
-	  {
-	    extern void free();
-	    sp_scan(free,NULL,spt_users);
-	    free(spt_users);
-	    spt_users = NULL;
-	  }
+	  sp_scan(free_spu,NULL,spt_users);
+	  free((void*)spt_users);
+	  spt_users = NULL;
 #endif	/* HAVE_SOCKET */
 	}
 	exit(EX_OK);
@@ -1820,7 +1823,7 @@ biff(hostname, username, offset)
 	/* Could do this with  getservbyname() - but sometimes (with NIS
 	   on loaded Suns) it takes AGES...  Hardwiring works as well.   */
 
-	symid = symbol(hostname);
+	symid = symbol((void*)hostname);
 	if (spt_hosts == NULL)
 	  spt_hosts = sp_init();
 	spl = sp_lookup(symid, spt_hosts);
@@ -1834,7 +1837,7 @@ biff(hostname, username, offset)
 	  biffaddr.sin_port = htons(BIFF_PORT);
 	  bap = (struct sockaddr_in *)emalloc(sizeof(struct sockaddr_in));
 	  *bap = biffaddr;
-	  sp_install(symid, (char *)bap, 0, spt_hosts);
+	  sp_install(symid, (void*) bap, 0, spt_hosts);
 	} else
 	  biffaddr = *(struct sockaddr_in *)spl->data;
 	buf = emalloc(3+strlen(username)+20);
@@ -1903,7 +1906,7 @@ readrwho()
 	    username[NMAX] = 0;
 	    /* add to data structure */
 
-	    symid = symbol(username);
+	    symid = symbol((void*)username);
 	    if ((spl = sp_lookup(symid, spt_users)) == NULL)
 	      continue;
 	    uhp = (struct userhost *)spl->data;
@@ -1930,7 +1933,7 @@ rbiff(nbp)
 	struct userhost *uhp;
 	spkey_t symid;
 
-	symid = symbol(nbp->user);
+	symid = symbol((void*)(nbp->user));
 	if ((spl = sp_lookup(symid, spt_users)) == NULL)
 	  return;
 	for (uhp = (struct userhost *)spl->data; uhp != NULL; uhp = uhp->next)
