@@ -35,7 +35,11 @@
 #include "zmsignal.h"
 #include <sysexits.h>
 /* #include <strings.h> */ /* poorly portable.. */
-#include <varargs.h>
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#else
+# include <varargs.h>
+#endif
 #include <fcntl.h>
 #include <sys/file.h>
 #include <sys/param.h>
@@ -56,8 +60,8 @@
 #undef NOERROR		/* Several SysV-streams using systems have NOERROR,
 			   which is not the same as  <arpa/nameser.h> has! */
 #endif
-#include "arpa/nameser.h"
-#include "resolv.h"
+#include <arpa/nameser.h>
+#include <resolv.h>
 
 #ifndef	BIND_VER
 #ifdef	GETLONG
@@ -218,7 +222,6 @@ int  servport = -1;
 time_t now;
 
 extern int errno;
-extern void warning(), report();
 #ifndef MALLOC_TRACE
 extern univptr_t emalloc();
 #endif
@@ -276,6 +279,13 @@ extern void stashmyaddresses();
 extern int cistrcmp(), cistrncmp();
 extern void getdaemon();
 
+#ifdef HAVE_STDARG_H
+extern void report __((char *fmt, ...));
+#else
+extern void report __(());
+#endif
+
+
 FILE *verboselog = NULL;
 int smtp_isopen = 0;
 
@@ -1964,7 +1974,7 @@ vcsetup(ipaddrcp, ipaddrlen, fdp, hostname, verboselog)
 	  return EX_TEMPFAIL;
 	}
 	if (wantreserved && getuid() == 0) {
-	  for (p = IPPORT_RESERVED-1; p >= (IPPORT_RESERVED/2); --p) {
+	  for (p = IPPORT_RESERVED-1; p >= (u_short)(IPPORT_RESERVED/2); --p) {
 	    sad.sin_port = htons(p);
 	    if (bind(s, (struct sockaddr *)&sad, sizeof sad) >= 0)
 	      break;
@@ -1981,7 +1991,7 @@ vcsetup(ipaddrcp, ipaddrlen, fdp, hostname, verboselog)
 	      return EX_UNAVAILABLE;
 	    }
 	  }
-	  if (p < (IPPORT_RESERVED/2)) {
+	  if (p < (u_short)(IPPORT_RESERVED/2)) {
 	    sprintf(remotemsg, "too many busy ports");
 	    notaryreport(NULL,FAILED,"4.4.0 (internal error, too many busy ports)","smtp; 500 (Internal error, too many busy ports)");
 	    if (conndebug)
@@ -2070,17 +2080,26 @@ int sig;
 	gotalarm = 1;
 }
 
+#ifdef HAVE_STDARG_H
+void
+rmsgappend(char *fmt, ...)
+#else
 void
 rmsgappend(va_alist)
 	va_dcl
+#endif
 {
 	va_list ap;
-	char *fmt, *arg;
+	char *arg;
 	char *cp = remotemsg + strlen(remotemsg);
 	char *cpend = remotemsg + sizeof remotemsg -1;
-
+#ifdef HAVE_STDARG_H
+	va_start(ap,fmt);
+#else
+	char *fmt;
 	va_start(ap);
 	fmt = va_arg(ap, char *);
+#endif
 
 	if (!fmt) fmt="(NULL)";
 	for (; *fmt != 0; ++fmt) {
@@ -2801,15 +2820,25 @@ smtp_ehlo(smtpfp, verboselog, strbuf)
  * where it doesn't work.
  */
 
+#ifdef HAVE_STDARG_H
+void report(char *fmt, ...)
+#else
 /* VARARGS */
 void
 report(va_alist)
 	va_dcl
+#endif
 {
 	va_list	ap;
-	char *cp, buf[8192];
-	
+	char buf[8192];
+
+#ifdef HAVE_STDARG_H
+	va_start(ap,fmt);
+#else
+	char *fmt;
 	va_start(ap);
+	fmt = va_arg(ap, char *);
+#endif
 	if (smtp_isopen)
 	  sprintf(buf, "-%s ", remotehost);
 	else
@@ -2819,14 +2848,13 @@ report(va_alist)
 	  sprintf(buf+strlen(buf), ">>%s ", logfile);
 	strcat(buf, "# ");
 #endif
-	cp = va_arg(ap, char *);
 #ifdef	HAVE_VPRINTF
-	vsprintf(buf+strlen(buf), cp, ap);
+	vsprintf(buf+strlen(buf), fmt, ap);
 #else	/* !HAVE_VPRINTF */
-	sprintf(buf+strlen(buf), cp, va_arg(ap, char *));
+	sprintf(buf+strlen(buf), fmt, va_arg(ap, char *));
 #endif	/* HAVE_VPRINTF */
-	for (cp = buf+strlen(buf); cp < buf + (eocmdline - cmdline); ++cp)
-	  *cp = ' ';
+	for (fmt = buf+strlen(buf); fmt < buf + (eocmdline - cmdline); ++fmt)
+	  *fmt = ' ';
 	buf[eocmdline-cmdline] = '\0';
 	strcpy(cmdline, buf);
 	va_end(ap);
